@@ -21,7 +21,6 @@ __author__ = 'Alexander Bruy'
 __date__ = 'October 2013'
 __copyright__ = '(C) 2013, Alexander Bruy'
 
-
 import os
 
 from qgis.core import (QgsRasterFileWriter,
@@ -40,7 +39,6 @@ pluginPath = os.path.split(os.path.split(os.path.dirname(__file__))[0])[0]
 
 
 class slope(GdalAlgorithm):
-
     INPUT = 'INPUT'
     BAND = 'BAND'
     AS_PERCENT = 'AS_PERCENT'
@@ -48,6 +46,7 @@ class slope(GdalAlgorithm):
     COMPUTE_EDGES = 'COMPUTE_EDGES'
     ZEVENBERGEN = 'ZEVENBERGEN'
     OPTIONS = 'OPTIONS'
+    EXTRA = 'EXTRA'
     OUTPUT = 'OUTPUT'
 
     def __init__(self):
@@ -84,6 +83,13 @@ class slope(GdalAlgorithm):
                 'class': 'processing.algs.gdal.ui.RasterOptionsWidget.RasterOptionsWidgetWrapper'}})
         self.addParameter(options_param)
 
+        extra_param = QgsProcessingParameterString(self.EXTRA,
+                                                   self.tr('Additional command-line parameters'),
+                                                   defaultValue=None,
+                                                   optional=True)
+        extra_param.setFlags(extra_param.flags() | QgsProcessingParameterDefinition.FlagAdvanced)
+        self.addParameter(extra_param)
+
         self.addParameter(QgsProcessingParameterRasterDestination(self.OUTPUT, self.tr('Slope')))
 
     def name(self):
@@ -136,4 +142,8 @@ class slope(GdalAlgorithm):
         if options:
             arguments.extend(GdalUtils.parseCreationOptions(options))
 
+        if self.EXTRA in parameters and parameters[self.EXTRA] not in (None, ''):
+            extra = self.parameterAsString(parameters, self.EXTRA, context)
+            arguments.append(extra)
+
         return [self.commandName(), GdalUtils.escapeAndJoin(arguments)]
